@@ -1,7 +1,7 @@
 package HTTP::Tiny::ProgressAny;
 
-our $DATE = '2015-01-22'; # DATE
-our $VERSION = '0.02'; # VERSION
+our $DATE = '2015-01-23'; # DATE
+our $VERSION = '0.03'; # VERSION
 
 use 5.010001;
 use strict;
@@ -49,7 +49,8 @@ sub _data_callback {
             pos => $new_pos,
             message => sub {
                 my @msg = (
-                    "Downloading ", $url, " ",
+                    "<elspan prio=2>Downloading </elspan>",
+                    "<elspan prio=3 truncate=middle>", $url, " </elspan>",
                     format_metric($new_pos),
                 );
                 if ($progress->target) {
@@ -91,7 +92,7 @@ HTTP::Tiny::ProgressAny - See progress for your HTTP::Tiny requests
 
 =head1 VERSION
 
-This document describes version 0.02 of HTTP::Tiny::ProgressAny (from Perl distribution HTTP-Tiny-ProgressAny), released on 2015-01-22.
+This document describes version 0.03 of HTTP::Tiny::ProgressAny (from Perl distribution HTTP-Tiny-ProgressAny), released on 2015-01-23.
 
 =head1 SYNOPSIS
 
